# xpdAcq

[![test](https://github.com/xpdAcq/xpdAcq/actions/workflows/test.yml/badge.svg)](https://github.com/xpdAcq/xpdAcq/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/xpdAcq/xpdAcq/branch/master/graph/badge.svg)](https://codecov.io/gh/xpdAcq/xpdAcq)
[![Anaconda-Server Badge](https://anaconda.org/nsls2forge/xpdacq/badges/version.svg)](https://anaconda.org/nsls2forge/xpdacq)

Acquisition packages for XPD-28 beamline at BNL

# Installation

Fork and clone this repo. Run the command in a terminal.

``bash install.sh <give a name to the conda environment>``

This will create a new conda environment and install the xpdacq in it.
